@@ -13,8 +13,8 @@ fn ratchet_enc_single() {
     let (mut bob_ratchet, public_key) = Ratchet::init_bob(sk);
     let mut alice_ratchet = Ratchet::init_alice(sk, public_key);
     let data = include_bytes!("../src/header.rs").to_vec();
-    let (header, encrypted, nonce) = alice_ratchet.ratchet_encrypt(&data);
-    let decrypted = bob_ratchet.ratchet_decrypt(&header, &encrypted, &nonce);
+    let (header, encrypted, nonce) = alice_ratchet.ratchet_encrypt(&data, b"");
+    let decrypted = bob_ratchet.ratchet_decrypt(&header, &encrypted, &nonce, b"");
     assert_eq!(data, decrypted)
 }
 
@@ -24,10 +24,10 @@ fn ratchet_enc_skip() {
     let (mut bob_ratchet, public_key) = Ratchet::init_bob(sk);
     let mut alice_ratchet = Ratchet::init_alice(sk, public_key);
     let data = include_bytes!("../src/header.rs").to_vec();
-    let (header1, encrypted1, nonce1) = alice_ratchet.ratchet_encrypt(&data);
-    let (header2, encrypted2, nonce2) = alice_ratchet.ratchet_encrypt(&data);
-    let decrypted2 = bob_ratchet.ratchet_decrypt(&header2, &encrypted2, &nonce2);
-    let decrypted1 = bob_ratchet.ratchet_decrypt(&header1, &encrypted1, &nonce1);
+    let (header1, encrypted1, nonce1) = alice_ratchet.ratchet_encrypt(&data, b"");
+    let (header2, encrypted2, nonce2) = alice_ratchet.ratchet_encrypt(&data, b"");
+    let decrypted2 = bob_ratchet.ratchet_decrypt(&header2, &encrypted2, &nonce2, b"");
+    let decrypted1 = bob_ratchet.ratchet_decrypt(&header1, &encrypted1, &nonce1, b"");
     let comp_res = decrypted1 == data && decrypted2 == data;
     assert!(comp_res)
 }
@@ -38,7 +38,7 @@ fn ratchet_panic_bob() {
     let sk = [1; 32];
     let (mut bob_ratchet, _) = Ratchet::init_bob(sk);
     let data = include_bytes!("../src/header.rs").to_vec();
-    let (_, _, _) = bob_ratchet.ratchet_encrypt(&data);
+    let (_, _, _) = bob_ratchet.ratchet_encrypt(&data, b"");
 }
 
 #[test]
@@ -47,10 +47,10 @@ fn ratchet_encryt_decrypt_four() {
     let data = include_bytes!("../src/dh.rs").to_vec();
     let (mut bob_ratchet, public_key) = Ratchet::init_bob(sk);
     let mut alice_ratchet = Ratchet::init_alice(sk, public_key);
-    let (header1, encrypted1, nonce1) = alice_ratchet.ratchet_encrypt(&data);
-    let decrypted1 = bob_ratchet.ratchet_decrypt(&header1, &encrypted1, &nonce1);
-    let (header2, encrypted2, nonce2) = bob_ratchet.ratchet_encrypt(&data);
-    let decrypted2 = alice_ratchet.ratchet_decrypt(&header2, &encrypted2, &nonce2);
+    let (header1, encrypted1, nonce1) = alice_ratchet.ratchet_encrypt(&data, b"");
+    let decrypted1 = bob_ratchet.ratchet_decrypt(&header1, &encrypted1, &nonce1, b"");
+    let (header2, encrypted2, nonce2) = bob_ratchet.ratchet_encrypt(&data, b"");
+    let decrypted2 = alice_ratchet.ratchet_decrypt(&header2, &encrypted2, &nonce2, b"");
     let comp_res = decrypted1 == data && decrypted2 == data;
     assert!(comp_res)
 }
@@ -80,8 +80,8 @@ fn ratchet_ench_enc_single() {
                                                          shared_hka,
                                                          shared_nhkb);
     let data = include_bytes!("../src/header.rs").to_vec();
-    let (header, encrypted, nonce) = alice_ratchet.ratchet_encrypt(&data);
-    let decrypted = bob_ratchet.ratchet_decrypt(&header, &encrypted, &nonce);
+    let (header, encrypted, nonce) = alice_ratchet.ratchet_encrypt(&data, b"");
+    let decrypted = bob_ratchet.ratchet_decrypt(&header, &encrypted, &nonce, b"");
     assert_eq!(data, decrypted)
 }
 
@@ -98,10 +98,10 @@ fn ratchet_ench_enc_skip() {
                                                          shared_hka,
                                                          shared_nhkb);
     let data = include_bytes!("../src/header.rs").to_vec();
-    let (header1, encrypted1, nonce1) = alice_ratchet.ratchet_encrypt(&data);
-    let (header2, encrypted2, nonce2) = alice_ratchet.ratchet_encrypt(&data);
-    let decrypted2 = bob_ratchet.ratchet_decrypt(&header2, &encrypted2, &nonce2);
-    let decrypted1 = bob_ratchet.ratchet_decrypt(&header1, &encrypted1, &nonce1);
+    let (header1, encrypted1, nonce1) = alice_ratchet.ratchet_encrypt(&data, b"");
+    let (header2, encrypted2, nonce2) = alice_ratchet.ratchet_encrypt(&data, b"");
+    let decrypted2 = bob_ratchet.ratchet_decrypt(&header2, &encrypted2, &nonce2, b"");
+    let decrypted1 = bob_ratchet.ratchet_decrypt(&header1, &encrypted1, &nonce1, b"");
     let comp_res = decrypted1 == data && decrypted2 == data;
     assert!(comp_res)
 }
@@ -116,7 +116,7 @@ fn ratchet_ench_panic_bob() {
                                                                    shared_hka,
                                                                    shared_nhkb);
     let data = include_bytes!("../src/header.rs").to_vec();
-    let (_, _, _) = bob_ratchet.ratchet_encrypt(&data);
+    let (_, _, _) = bob_ratchet.ratchet_encrypt(&data, b"");
 }
 
 #[test]
@@ -129,10 +129,10 @@ fn ratchet_ench_decrypt_four() {
                                                                    shared_nhkb);
     let mut alice_ratchet = RatchetEncHeader::init_alice(sk, public_key, shared_hka, shared_nhkb);
     let data = include_bytes!("../src/dh.rs").to_vec();
-    let (header1, encrypted1, nonce1) = alice_ratchet.ratchet_encrypt(&data);
-    let decrypted1 = bob_ratchet.ratchet_decrypt(&header1, &encrypted1, &nonce1);
-    let (header2, encrypted2, nonce2) = bob_ratchet.ratchet_encrypt(&data);
-    let decrypted2 = alice_ratchet.ratchet_decrypt(&header2, &encrypted2, &nonce2);
+    let (header1, encrypted1, nonce1) = alice_ratchet.ratchet_encrypt(&data, b"");
+    let decrypted1 = bob_ratchet.ratchet_decrypt(&header1, &encrypted1, &nonce1, b"");
+    let (header2, encrypted2, nonce2) = bob_ratchet.ratchet_encrypt(&data, b"");
+    let decrypted2 = alice_ratchet.ratchet_decrypt(&header2, &encrypted2, &nonce2, b"");
     let comp_res = decrypted1 == data && decrypted2 == data;
     assert!(comp_res)
 }
\ No newline at end of file
